@charset "UTF-8";
.wp-block-separator {
  border-top: 2px solid currentColor;
  border-left: none;
  border-right: none;
  border-bottom: none;
}

:root :where(.wp-block-separator.is-style-dots) {
  text-align: center;
  line-height: 1;
  height: auto;
}
:root :where(.wp-block-separator.is-style-dots)::before {
  content: "···";
  color: currentColor;
  font-size: 1.5em;
  letter-spacing: 2em;
  /*rtl:ignore*/
  padding-left: 2em;
  font-family: serif;
}

.wp-block-separator.is-style-dots {
  background: none !important;
  border: none !important;
}